#ifndef FEAT_SKILL_H
#define FEAT_SKILL_H

/**
 * \file feat_skill.h
 * \brief Feature e skill
 *
 * Dichiarazioni feature e skill
 */

#include <string>
using namespace std;

/// Classe Skill per descrivere le abilit
/**
 * La classe Skill  composta di una stringa che descrive l'abilita e da un int
 * che la quantifica.
 * Ha un costruttore del tipo Skill("nuotare",10) ed una relazione d'ordine
 * che confronta il solo nome (identifica quindi abilit con diversi numeri)
 * per permetterne l'inserimento e la ricerca sulla base del nome in container
 * associativi.<br>
 * es. TempSet<Skill> t;<br>
 * t.equal_range(Skill("nuotare")) restituir una coppia di iteratori che contengono
 * tutte le skill "nuotare" con relativi pesi.
 */
class Skill{
	private:
		string name;	///< Nome della skill
		int qu;		///< Peso della skill
	public:
		/// Restituisce il nome
		string n() const {return name;}
		/// Restituisce il peso
		int q() const {return qu;}
		/// Costruttore
		/**
		 * \param s il nome della skill (es. "nuotare")
		 * \param x il peso della skill (es. 10)
		 * il peso ha un default = 0 per poterlo omettere in fase di ricerca
		 */
		Skill(string s, int x=0) : name(s), qu(x) {}
		/// Ordinamento in base al solo nome
		friend bool operator<(const Skill& sx, const Skill& dx){
			sx.name<dx.name;
		}
};

/**
  * \var typedef string Feat
  * \brief Feat  il nome di feature (es. invulnerabilit)
  *
  * Feat  semplicemente una stringa
  */

typedef string Feat;

/**
 * \example feat_skill_test.cc
 */

#endif
